FlutterVault class

A utility class containing common helper methods for Flutter development.

Constructors

FlutterVault()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debounce(dynamic func, [int? milliseconds]) → void
Debounces the execution of a function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited